==> interactive-style-1.1.1.tgz: package/src/components/Head/example.js <==
import React from 'react';
import ReactDOM from 'react-dom';
import Page from 'Common/Page/';
import CodeBlock from 'Common/CodeBlock';

import Head from './index';

class App extends React.Component {
  state = {
    title: 'My Page Title',
    publishPath: 'interactives/2019/politico-style-demo/',
    social: {
      'fbook': {
        'card_title': '',
        'card_description': '',
      },
      'twitter': {
        'card_title': '',
        'share_tweet': '',
        'card_description': '',
      },
      'image': {
        'url': '',
        'alt': '<Text>',
        'type': 'image/jpeg',
        'width': '600',
        'height': '300',
      },
    },

    // Explicitly passing data
    // utagConfig: {
    //   'pageName': 'what-works-next-2019-seattle',
    //   'siteSection': 'politics',
    //   'pageType': 'interactives',
    //   'adUnitSection': 'politics',
    //   'freePaidContent': 'free',
    //   'publishPath': 'interactives/2019/what-works-next-2019-seattle/',
    //   'authors': [
    //     {
    //       'link': 'https://www.politico.com/',
    //       'name': 'Polly Politico',
    //     },
    //   ],
    // },

    // Passing a complete override
    // utagOverride: true,
    // utagConfig: {
    //   page_level_1: 'interactives',
    //   free_paid_content: 'free',
    //   ad_unit_section: 'magazine-what-works-2019-story',
    //   distribution_channel: 'politico',
    //   content_tag: 'What Works|Transportation',
    //   series: 'what-works-2019',
    //   subseries: 'transportation',
    //   page_type: 'interactives',
    //   site_domain: 'www.politico.com',
    //   internal_site_id: 'politico-magazine',
    //   page_name: 'whatworksnext-seattle',
    // },
  };

  render() {
    return (
      <Page title='Head'>
        <Head {...this.state} />
        <CodeBlock
          value={`import { Head } from '@politico/interactive-style';

const title = "My Page Title"
const publishPath = "interactives/2019/politico-style-demo/"
const social = {
  'fbook': {
    'card_title': '',
    'card_description': '',
  },
  'twitter': {
    'card_title': '',
    'share_tweet': '',
    'card_description': '',
  },
  'image': {
    'url': '',
    'alt': '<Text>',
    'type': 'image/jpeg',
    'width': '600',
    'height': '300',
  },
}

<Head tilte={title} publishPath={publishPath} social={social} />

/**
 * You can also choose to exclude certain sections with the "no-sectionName" props.
 * These include:
 * - no-html
 * - no-title
 * - no-meta
 * - no-canonical
 * - no-favicon
 * - no-social
 * - no-battletoads
 * - no-fontawesome
 * - no-typekit
 * - no-jquery
 * - no-adBlockCookie
 * - no-utag
 */

<Head tilte={title} publishPath={publishPath} no-typekit no-social />
        `}
        />
      </Page>
    );
  }
}

export default App;

ReactDOM.render(<App />, document.getElementById('app'));

==> interactive-style-1.3.0.tgz: package/src/components/Head/example.js <==
import React from 'react';
import ReactDOM from 'react-dom';
import Page from 'Common/Page/';
import CodeBlock from 'Common/CodeBlock';

import Head from './index';

class App extends React.Component {
  state = {
    title: 'My Page Title',
    publishPath: 'interactives/2019/politico-style-demo/',
    social: {
      'fbook': {
        'card_title': '',
        'card_description': '',
      },
      'twitter': {
        'card_title': '',
        'share_tweet': '',
        'card_description': '',
      },
      'image': {
        'url': '',
        'alt': '<Text>',
        'type': 'image/jpeg',
        'width': '600',
        'height': '300',
      },
    },

    // Explicitly passing data
    // utagConfig: {
    //   'pageName': 'what-works-next-2019-seattle',
    //   'siteSection': 'politics',
    //   'pageType': 'interactives',
    //   'adUnitSection': 'politics',
    //   'freePaidContent': 'free',
    //   'publishPath': 'interactives/2019/what-works-next-2019-seattle/',
    //   'authors': [
    //     {
    //       'link': 'https://www.politico.com/',
    //       'name': 'Polly Politico',
    //     },
    //   ],
    // },

    // Passing a complete override
    // utagOverride: true,
    // utagConfig: {
    //   page_level_1: 'interactives',
    //   free_paid_content: 'free',
    //   ad_unit_section: 'magazine-what-works-2019-story',
    //   distribution_channel: 'politico',
    //   content_tag: 'What Works|Transportation',
    //   series: 'what-works-2019',
    //   subseries: 'transportation',
    //   page_type: 'interactives',
    //   site_domain: 'www.politico.com',
    //   internal_site_id: 'politico-magazine',
    //   page_name: 'whatworksnext-seattle',
    // },
  };

  render() {
    return (
      <Page title='Head'>
        <Head {...this.state} site='magazine' />
        <CodeBlock
          value={`import { Head } from '@politico/interactive-style';

const title = "My Page Title"
const publishPath = "interactives/2019/politico-style-demo/"
const site = 'core' // ["core", "magazine"]
const social = {
  'fbook': {
    'card_title': '',
    'card_description': '',
  },
  'twitter': {
    'card_title': '',
    'share_tweet': '',
    'card_description': '',
  },
  'image': {
    'url': '',
    'alt': '<Text>',
    'type': 'image/jpeg',
    'width': '600',
    'height': '300',
  },
}

<Head tilte={title} publishPath={publishPath} social={social} site={site} />

/**
 * You can also choose to exclude certain sections with the "no-sectionName" props.
 * These include:
 * - no-html
 * - no-title
 * - no-meta
 * - no-canonical
 * - no-favicon
 * - no-social
 * - no-battletoads
 * - no-fontawesome
 * - no-typekit
 * - no-jquery
 * - no-adBlockCookie
 * - no-utag
 */

<Head tilte={title} publishPath={publishPath} no-typekit no-social />
        `}
        />
      </Page>
    );
  }
}

export default App;

ReactDOM.render(<App />, document.getElementById('app'));
